// Define custom filters here!
const filters = {};

filters.asIdentifier = function(str) {
  if (!str) return '';
  return str.replace(/([a-z])([A-Z])/g, '$1_$2').toLowerCase().replace(/(^[^a-z]+)|([^a-z0-9_?!]+)/g, '_').replace(/(^_+)|(_+$)/g, '');
};

filters.camelToSnake = function(str) {
  if (!str) return '';
  return str.replace(/([a-z])([A-Z])/g, '$1_$2').replace(/([a-zA-Z])([0-9])/g, '$1_$2').replace(/_+/g, '_').replace(/^_|_$/g, '').toLowerCase();
}

// Turns "snake_case_strings" into "Snake Case Strings"
filters.snakeToTitle = function(str) {
  if (!str) return '';
  return str.split('_').map(function(item) {
    return item.charAt(0).toUpperCase() + item.substring(1);
  }).join(' ');
};

filters.camelToTitle = function(str) {
  if (!str) return '';
  return filters.snakeToTitle(filters.camelToSnake(str));
}

// https://stackoverflow.com/a/9462382/2990656
filters.humanReadableNumber = function(num, digits = 4) {
  var si = [
    { value: 1E18, symbol: "E" },
    { value: 1E15, symbol: "P" },
    { value: 1E12, symbol: "T" },
    { value: 1E9,  symbol: "B" },
    { value: 1E6,  symbol: "M" },
    { value: 1E3,  symbol: "K" }
  ], rx = /\.0+$|(\.[0-9]*[1-9])0+$/, i;
  for (i = 0; i < si.length; i++) {
    if (num >= si[i].value) {
      return (num / si[i].value).toFixed(digits).replace(rx, "$1") + si[i].symbol;
    }
  }
  return num.toFixed(digits).replace(rx, "$1");
}

export default filters;
