import * as Dripicons from './assets/dripicons'
import plugins from './plugins'
import components from './components'
import filters from './filters'
import axios from 'axios'
import VueAxios from 'vue-axios'
import moment from 'moment'
import Toaster from 'v-toaster'
import VueSvgicon from 'vue-svgicon'
import Ripple from 'vue-ripple-directive'
import pluralize from 'pluralize'

// import './lib/novillus-loader.js'
// import './lib/novillus-loader.css'


// click-confirm not working as expected. Removing for now.
// import ClickConfirm from 'click-confirm'

// You need a specific loader for CSS files like https://github.com/webpack/css-loader
import 'v-toaster/dist/v-toaster.css'

const NovillusVue = {
  install: function(Vue, options) {
    options = options || {};
    if (!Vue._novillus_vue_installed) {
      Vue._novillus_vue_installed = true;

      // Register Novillus Vue plugins.
      for (var plugin in plugins) {
        if (plugins.hasOwnProperty(plugin)) {
          Vue.use(plugins[plugin], options[plugin]);
        }
      }

      // Register other plugins.
      Vue.use(VueSvgicon);
      Vue.use(VueAxios, axios)
      Vue.use(Toaster, {timeout: 3000})


      Vue.directive('ripple', Ripple);

      // Add in moment.js for date formatting.
      Vue.prototype.moment = moment;

      // Add in pluralize for random pluralization needs.
      Vue.prototype.pluralize = pluralize;

      for (var component in components) {
        if (components.hasOwnProperty(component)) {
          Vue.component(component, components[component]);
        }
      }
      // Register components
      // Vue.component('clickConfirm', ClickConfirm);

      // Install filters
      for (var filter in filters) {
        if (filters.hasOwnProperty(filter)) {
          Vue.filter(filter, filters[filter]);
        }
      }

      let csrf = document.getElementsByName('csrf-token')

      if (csrf.length) {
        axios.defaults.headers.common['X-CSRF-Token'] = csrf[0].content
        axios.defaults.headers.common['Accept'] = 'application/json'
      }

    }
  }
}

export default NovillusVue;
